summaryrefslogtreecommitdiff
path: root/indra/newview/llappviewerwin32.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'indra/newview/llappviewerwin32.cpp')
-rw-r--r--indra/newview/llappviewerwin32.cpp11
1 files changed, 9 insertions, 2 deletions
diff --git a/indra/newview/llappviewerwin32.cpp b/indra/newview/llappviewerwin32.cpp
index a951338138..0620b625d9 100644
--- a/indra/newview/llappviewerwin32.cpp
+++ b/indra/newview/llappviewerwin32.cpp
@@ -176,10 +176,17 @@ namespace
LLAppViewer* app = LLAppViewer::instance();
if (!app->isSecondInstance() && !app->errorMarkerExists())
{
// If marker doesn't exist, create a marker with 'other' code for next launch
// otherwise don't override existing file
// Any unmarked crashes will be considered as freezes
- app->createErrorMarker(LAST_EXEC_OTHER_CRASH);
+ if (app->logoutRequestSent())
+ {
+ app->createErrorMarker(LAST_EXEC_LOGOUT_CRASH);
+ }
+ else
+ {
+ app->createErrorMarker(LAST_EXEC_OTHER_CRASH);
+ }
}
} // MDSCB_EXCEPTIONCODE
@@ -176,10 +176,17 @@ namespace
if (!app->isSecondInstance() && !app->errorMarkerExists())
{
- // If marker doesn't exist, create a marker with 'other' code for next launch
+ // If marker doesn't exist, create a marker with 'other' or 'logout' code for next launch
// otherwise don't override existing file
// Any unmarked crashes will be considered as freezes